@@ -5,8 +5,10 @@ Net::OSCAR::Connection::Chat -- OSCAR chat connections
 =cut
 
 package Net::OSCAR::Connection::Chat;
+BEGIN {
+  $Net::OSCAR::Connection::Chat::VERSION = '1.927';
+}
 
-$VERSION = '1.926';
 $REVISION = '$Revision$';
 
 use strict;
@@ -14,7 +16,7 @@ use Carp;
 
 use Net::OSCAR::TLV;
 use Net::OSCAR::Callbacks;
-use vars qw(@ISA $VERSION);
+use vars qw(@ISA);
 use Net::OSCAR::Common qw(:all);
 use Net::OSCAR::Constants;
 use Net::OSCAR::Utility;
