@@ -1,16 +1,24 @@
 =pod
 
+=head1 NAME
+
 Net::OSCAR::Constants -- internal Net::OSCAR constants
 
+=head1 VERSION
+
+version 1.927
+
 =cut
 
 package Net::OSCAR::Constants;
+BEGIN {
+  $Net::OSCAR::Constants::VERSION = '1.927';
+}
 
-$VERSION = '1.926';
 $REVISION = '$Revision$';
 
 use strict;
-use vars qw(@ISA @EXPORT $VERSION);
+use vars qw(@ISA @EXPORT);
 use Scalar::Util qw(dualvar);
 use Net::OSCAR::TLV;
 require Exporter;
@@ -167,4 +175,4 @@ use constant ICQ_META_INFO => {
 };
 use constant ICQ_META_INFO_INVERSE => { map { ICQ_META_INFO()->{$_} => $_ } keys %{ICQ_META_INFO()} };
 
-1;
+1;
\ No newline at end of file
