@@ -1,19 +1,29 @@
 =pod
 
+=head1 NAME
+
 Net::OSCAR::TLV -- tied hash for OSCAR TLVs
 
+=head1 VERSION
+
+version 1.927
+
+=head1 DESCRIPTION
+
 Keys in hashes tied to this class will be treated as numbers.
 This class also preserves the ordering of its keys.
 
 =cut
 
 package Net::OSCAR::TLV;
+BEGIN {
+  $Net::OSCAR::TLV::VERSION = '1.927';
+}
 
-$VERSION = '1.926';
 $REVISION = '$Revision$';
 
 use strict;
-use vars qw($VERSION @EXPORT @ISA);
+use vars qw(@EXPORT @ISA);
 
 require Exporter;
 @ISA = qw(Exporter);
@@ -143,4 +153,4 @@ sub tlv(;@) {
 }
 
 
-1;
+1;
\ No newline at end of file
