@@ -1,16 +1,24 @@
 =pod
 
+=head1 NAME
+
 Net::OSCAR::Utility -- internal utility functions for Net::OSCAR
 
+=head1 VERSION
+
+version 1.927
+
 =cut
 
 package Net::OSCAR::Utility;
+BEGIN {
+  $Net::OSCAR::Utility::VERSION = '1.927';
+}
 
-$VERSION = '1.926';
 $REVISION = '$Revision$';
 
 use strict;
-use vars qw(@ISA @EXPORT $VERSION);
+use vars qw(@ISA @EXPORT);
 use Digest::MD5 qw(md5);
 use Carp;
 
@@ -293,4 +301,4 @@ sub hash_iter_reset($) {
 	while((undef, undef) = each(%{$_[0]})) {}
 }
 
-1;
+1;
\ No newline at end of file
