@@ -1,7 +1,15 @@
 =pod
 
+=head1 NAME
+
 Net::OSCAR::XML -- XML functions for Net::OSCAR
 
+=head1 VERSION
+
+version 1.927
+
+=head1 DESCRIPTION
+
 We're doing the fancy-schmancy Protocol.xml stuff here, so I'll explain it here.
 
 Protocol.xml contains a number of "OSCAR protocol elements".  One E<lt>defineE<gt> block
@@ -21,12 +29,14 @@ for every protocol element.
 =cut
 
 package Net::OSCAR::XML;
+BEGIN {
+  $Net::OSCAR::XML::VERSION = '1.927';
+}
 
-$VERSION = '1.926';
 $REVISION = '$Revision$';
 
 use strict;
-use vars qw(@ISA @EXPORT $VERSION);
+use vars qw(@ISA @EXPORT);
 use Carp;
 use Data::Dumper;
 
@@ -333,4 +343,4 @@ sub snac_to_protobit(%) {
 	}
 }
 
-1;
+1;
\ No newline at end of file
